clc
clear all

%% Input data

% This database contains 4 columns:
% 1) Id of the row
% 2) Motion capture value (m_k) from eq. (9)
% 3) Day of the experiment
% 4) Number video of the day of the experiment (approximately 2h of video
% sequence per video)
load records.mat
n = size(records,1);

fs = 6;                   % frames per second
disp(['A total of ' num2str(floor(n/fs/60/60)) ' hours'])

%% Moving averages of motion per day
K = 90;  % K=90->15sec; 
mk = records(:,2);
mk_hat = tsmovavg(mk','s',K); mk_hat = mk_hat';
records_hat = [records(:,1) mk_hat records(:,3:4)];

% remove null values
nan = sum(isnan(mk_hat));
records_hat = records_hat(nan+1:end,:);
n2 = size(records_hat,1);

%% Load time slots statistics (stats_ts)

% This database contains 8 columns
% 1-6) Mr_min, Mr_q1, Mr_med, Mr_q3, Mr_max, QMr (every 15 secs)
% 7) Day of the experiment
% 8) Number video of the day of the experiment
load stats.mat

%% Load clusters (k=32) created in pre-infection period

% This database contains 8 columns
% 1) cluster number
% 2) number of Mr (time intervals) in cluster
% 3-7) Mr_min, Mr_q1, Mr_med, Mr_q3, Mr_max values of the centroid
% 8) percentage of Mr (time intervals) in cluster
% 9) group G1, G2 or G3
load clusters.mat

plotClusters 

%% daily motion & runstests (3 min)

% This database contains 1 column 
% 1) The final group (G1, G2 or G3) of each interval Mr of the entire experiment
% (pre-postinfection)
load idxG.mat

dailyMotion
runs



